is_check_request_limited

Function is_check_request_limited 

pub fn is_check_request_limited(
    enrolment_check_requested_at: Option<DateTime<Utc>>,
    enrolment_checked_at: Option<DateTime<Utc>>,
    now: DateTime<Utc>,
) -> bool
Whether a check request would be refused as too soon right now, which is when the buttons that make one are hidden.