pub struct EnrolmentCheckStart {
pub credit_registration_id: Uuid,
pub group: EnrolmentCheckGroup,
pub anchor_at: DateTime<Utc>,
pub scheduled: ScheduledEnrolmentCheck,
pub source: EnrolmentCheckSource,
}Expand description
The schedule a row starts when it first waits for an enrolment, decided by the preconditions recompute.
Fields
credit_registration_id: Uuidgroup: EnrolmentCheckGroupanchor_at: DateTime<Utc>scheduled: ScheduledEnrolmentChecksource: EnrolmentCheckSourceTrait Implementations
Sourceimpl Clone for EnrolmentCheckStart
impl Clone for EnrolmentCheckStart
Sourcefn clone(&self) -> EnrolmentCheckStart
fn clone(&self) -> EnrolmentCheckStart
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EnrolmentCheckStart
impl Debug for EnrolmentCheckStart
Sourceimpl PartialEq for EnrolmentCheckStart
impl PartialEq for EnrolmentCheckStart
impl StructuralPartialEq for EnrolmentCheckStart