async fn add_seen_enrolment_ids(
conn: &mut PgConnection,
id: Uuid,
enrolment_ids: &[String],
) -> ModelResult<()>Expand description
Adds the enrolment ids a check saw to the row’s seen set, which also marks it checked for
wake_for_roster_listing.