pub fn is_check_request_limited(
enrolment_check_requested_at: Option<DateTime<Utc>>,
enrolment_checked_at: Option<DateTime<Utc>>,
now: DateTime<Utc>,
) -> boolExpand description
Whether a check request would be refused as too soon right now, which is when the buttons that make one are hidden.